searchData={"items":[{"type":"module","title":"ExDbug","doc":"# ExDbug\n\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_dbug.svg)](https://hex.pm/packages/ex_dbug)\n[![Docs](https://img.shields.io/badge/hex-docs-blue.svg)](https://hexdocs.pm/ex_dbug)\n\nDebug utility for Elixir applications, inspired by the Node.js 'debug' package. \nProvides namespace-based filtering, rich metadata support, and compile-time optimization.","ref":"ExDbug.html"},{"type":"module","title":"Features - ExDbug","doc":"* 🔍 Namespace-based debug output filtering\n* 📊 Rich metadata support with customizable formatting\n* ⚡ Zero runtime cost when disabled (compile-time optimization)\n* 🌍 Environment variable-based filtering\n* 📝 Automatic metadata truncation for large values\n* 🔧 Configurable debug levels and context-based filtering\n* 📈 Value tracking through pipelines\n* ⏱️ Optional timing and stack trace information","ref":"ExDbug.html#module-features"},{"type":"module","title":"Installation - ExDbug","doc":"Add `ex_dbug` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_dbug, \"~> 1.0\"}\n  ]\nend\n```","ref":"ExDbug.html#module-installation"},{"type":"module","title":"Basic Usage - ExDbug","doc":"Add `use ExDbug` to your module and use the `dbug/1,2,3` or `error/1,2,3` macros:\n\n```elixir\ndefmodule MyApp.Worker do\n  use ExDbug, context: :worker\n\n  def process(data) do\n    dbug(\"Processing data\", size: byte_size(data))\n    # ... processing logic\n    dbug(\"Completed processing\", status: :ok)\n  end\nend\n```","ref":"ExDbug.html#module-basic-usage"},{"type":"module","title":"Configuration - ExDbug","doc":"","ref":"ExDbug.html#module-configuration"},{"type":"module","title":"Compile-Time Configuration - ExDbug","doc":"In your `config.exs`:\n\n```elixir\nconfig :ex_dbug,\n  enabled: true,  # Set to false to compile out all debug calls\n  config: [      # Default options for all ExDbug uses\n    max_length: 500,\n    truncate_threshold: 100,\n    include_timing: true,\n    include_stack: true,\n    max_depth: 3,\n    levels: [:debug, :error]\n  ]\n```","ref":"ExDbug.html#module-compile-time-configuration"},{"type":"module","title":"Runtime Configuration - ExDbug","doc":"Set the `DEBUG` environment variable to control which namespaces are logged:\n\n```bash\n# Enable all debug output\nDEBUG=\"*\" mix run\n\n# Enable specific namespace\nDEBUG=\"myapp:worker\" mix run\n\n# Enable multiple patterns\nDEBUG=\"myapp:*,other:thing\" mix run\n\n# Enable all except specific namespace\nDEBUG=\"*,-myapp:secret\" mix run\n```","ref":"ExDbug.html#module-runtime-configuration"},{"type":"module","title":"Advanced Usage - ExDbug","doc":"","ref":"ExDbug.html#module-advanced-usage"},{"type":"module","title":"Metadata Support - ExDbug","doc":"All debug macros accept metadata as keyword lists:\n\n```elixir\ndbug(\"User login\", \n  user_id: 123,\n  ip: \"192.168.1.1\",\n  timestamp: DateTime.utc_now()\n)\n```\n\nLong metadata values are automatically truncated based on configuration:\n```elixir\n# With default config (truncate_threshold: 100, max_length: 500)\ndbug(\"Big data\", data: String.duplicate(\"x\", 1000))\n# Output: [context] Big data data: \"xxxxx... (truncated)\"\n```","ref":"ExDbug.html#module-metadata-support"},{"type":"module","title":"Value Tracking - ExDbug","doc":"Debug values in pipelines without breaking the flow:\n\n```elixir\ndef process_payment(amount) do\n  amount\n  |> track(\"initial_amount\")\n  |> apply_fees()\n  |> track(\"with_fees\")\n  |> complete_transaction()\nend\n```","ref":"ExDbug.html#module-value-tracking"},{"type":"module","title":"Module Configuration - ExDbug","doc":"Configure ExDbug behavior per module:\n\n```elixir\nuse ExDbug,\n  context: :payment_processor,\n  max_length: 1000,\n  truncate_threshold: 200,\n  include_timing: true,\n  include_stack: false,\n  levels: [:debug, :error]\n```","ref":"ExDbug.html#module-module-configuration"},{"type":"module","title":"Debug Levels - ExDbug","doc":"Control which log levels are enabled:\n\n```elixir\n# Only show error messages\nuse ExDbug,\n  context: :critical_system,\n  levels: [:error]\n\n# Later in code\nerror(\"Critical failure\", error: err)  # This shows\ndbug(\"Processing\")                     # This doesn't\n```","ref":"ExDbug.html#module-debug-levels"},{"type":"module","title":"Output Format - ExDbug","doc":"Debug messages follow this format:\n```\n[Context] Message key1: value1, key2: value2\n```\n\nExamples:\n```\n[payment] Processing payment amount: 100, currency: \"USD\"\n[worker] Job completed status: :ok, duration_ms: 1500\n```","ref":"ExDbug.html#module-output-format"},{"type":"module","title":"Best Practices - ExDbug","doc":"1. Use descriptive context names matching your application structure\n2. Include relevant metadata for better debugging context\n3. Set appropriate DEBUG patterns for different environments\n4. Disable in production for zero overhead\n5. Use `track/2` for debugging pipeline transformations","ref":"ExDbug.html#module-best-practices"},{"type":"module","title":"Production Use - ExDbug","doc":"While ExDbug has minimal overhead when disabled, it's recommended to set \n`config :ex_dbug, enabled: false` in production unless debugging is specifically \nneeded. This ensures zero runtime cost as debug calls are compiled out completely.","ref":"ExDbug.html#module-production-use"},{"type":"macro","title":"ExDbug.dbug/2","doc":"","ref":"ExDbug.html#dbug/2"},{"type":"macro","title":"ExDbug.error/2","doc":"","ref":"ExDbug.html#error/2"},{"type":"function","title":"ExDbug.format_output/4","doc":"","ref":"ExDbug.html#format_output/4"},{"type":"macro","title":"ExDbug.track/2","doc":"","ref":"ExDbug.html#track/2"},{"type":"type","title":"ExDbug.debug_opts/0","doc":"","ref":"ExDbug.html#t:debug_opts/0"},{"type":"extras","title":"ExDbug","doc":"# ExDbug\n\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_dbug.svg)](https://hex.pm/packages/ex_dbug)\n[![Docs](https://img.shields.io/badge/hex-docs-blue.svg)](https://hexdocs.pm/ex_dbug)\n\nDebug utility for Elixir applications, inspired by the Node.js 'debug' package. \nProvides namespace-based filtering, rich metadata support, and compile-time optimization.","ref":"readme.html"},{"type":"extras","title":"Features - ExDbug","doc":"* 🔍 Namespace-based debug output filtering\n* 📊 Rich metadata support with customizable formatting\n* ⚡ Zero runtime cost when disabled (compile-time optimization)\n* 🌍 Environment variable-based filtering\n* 📝 Automatic metadata truncation for large values\n* 🔧 Configurable debug levels and context-based filtering\n* 📈 Value tracking through pipelines\n* ⏱️ Optional timing and stack trace information","ref":"readme.html#features"},{"type":"extras","title":"Installation - ExDbug","doc":"Add `ex_dbug` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_dbug, \"~> 1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Basic Usage - ExDbug","doc":"Add `use ExDbug` to your module and use the `dbug/1,2,3` or `error/1,2,3` macros:\n\n```elixir\ndefmodule MyApp.Worker do\n  use ExDbug, context: :worker\n\n  def process(data) do\n    dbug(\"Processing data\", size: byte_size(data))\n    # ... processing logic\n    dbug(\"Completed processing\", status: :ok)\n  end\nend\n```","ref":"readme.html#basic-usage"},{"type":"extras","title":"Configuration - ExDbug","doc":"","ref":"readme.html#configuration"},{"type":"extras","title":"Compile-Time Configuration - ExDbug","doc":"In your `config.exs`:\n\n```elixir\nconfig :ex_dbug,\n  enabled: true,  # Set to false to compile out all debug calls\n  config: [      # Default options for all ExDbug uses\n    max_length: 500,\n    truncate_threshold: 100,\n    include_timing: true,\n    include_stack: true,\n    max_depth: 3,\n    levels: [:debug, :error]\n  ]\n```","ref":"readme.html#compile-time-configuration"},{"type":"extras","title":"Runtime Configuration - ExDbug","doc":"Set the `DEBUG` environment variable to control which namespaces are logged:\n\n```bash\n# Enable all debug output\nDEBUG=\"*\" mix run\n\n# Enable specific namespace\nDEBUG=\"myapp:worker\" mix run\n\n# Enable multiple patterns\nDEBUG=\"myapp:*,other:thing\" mix run\n\n# Enable all except specific namespace\nDEBUG=\"*,-myapp:secret\" mix run\n```","ref":"readme.html#runtime-configuration"},{"type":"extras","title":"Advanced Usage - ExDbug","doc":"","ref":"readme.html#advanced-usage"},{"type":"extras","title":"Metadata Support - ExDbug","doc":"All debug macros accept metadata as keyword lists:\n\n```elixir\ndbug(\"User login\", \n  user_id: 123,\n  ip: \"192.168.1.1\",\n  timestamp: DateTime.utc_now()\n)\n```\n\nLong metadata values are automatically truncated based on configuration:\n```elixir\n# With default config (truncate_threshold: 100, max_length: 500)\ndbug(\"Big data\", data: String.duplicate(\"x\", 1000))\n# Output: [context] Big data data: \"xxxxx... (truncated)\"\n```","ref":"readme.html#metadata-support"},{"type":"extras","title":"Value Tracking - ExDbug","doc":"Debug values in pipelines without breaking the flow:\n\n```elixir\ndef process_payment(amount) do\n  amount\n  |> track(\"initial_amount\")\n  |> apply_fees()\n  |> track(\"with_fees\")\n  |> complete_transaction()\nend\n```","ref":"readme.html#value-tracking"},{"type":"extras","title":"Module Configuration - ExDbug","doc":"Configure ExDbug behavior per module:\n\n```elixir\nuse ExDbug,\n  context: :payment_processor,\n  max_length: 1000,\n  truncate_threshold: 200,\n  include_timing: true,\n  include_stack: false,\n  levels: [:debug, :error]\n```","ref":"readme.html#module-configuration"},{"type":"extras","title":"Debug Levels - ExDbug","doc":"Control which log levels are enabled:\n\n```elixir\n# Only show error messages\nuse ExDbug,\n  context: :critical_system,\n  levels: [:error]\n\n# Later in code\nerror(\"Critical failure\", error: err)  # This shows\ndbug(\"Processing\")                     # This doesn't\n```","ref":"readme.html#debug-levels"},{"type":"extras","title":"Output Format - ExDbug","doc":"Debug messages follow this format:\n```\n[Context] Message key1: value1, key2: value2\n```\n\nExamples:\n```\n[payment] Processing payment amount: 100, currency: \"USD\"\n[worker] Job completed status: :ok, duration_ms: 1500\n```","ref":"readme.html#output-format"},{"type":"extras","title":"Best Practices - ExDbug","doc":"1. Use descriptive context names matching your application structure\n2. Include relevant metadata for better debugging context\n3. Set appropriate DEBUG patterns for different environments\n4. Disable in production for zero overhead\n5. Use `track/2` for debugging pipeline transformations","ref":"readme.html#best-practices"},{"type":"extras","title":"Production Use - ExDbug","doc":"While ExDbug has minimal overhead when disabled, it's recommended to set \n`config :ex_dbug, enabled: false` in production unless debugging is specifically \nneeded. This ensures zero runtime cost as debug calls are compiled out completely.","ref":"readme.html#production-use"},{"type":"extras","title":"Contributing - ExDbug","doc":"1. Fork it\n2. Create your feature branch (`git checkout -b my-new-feature`)\n3. Commit your changes (`git commit -am 'Add some feature'`)\n4. Push to the branch (`git push origin my-new-feature`)\n5. Create new Pull Request","ref":"readme.html#contributing"},{"type":"extras","title":"License - ExDbug","doc":"MIT License - see LICENSE.md for details.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}